
Validated cryptographic modules
-------

**Description:**

The National Institute of Standards and Technology (NIST) issued the FIPS 140 Publication 
Series to coordinate the requirements and standards for cryptography modules that include 
both hardware and software components. Protection of a cryptographic module within a 
security system is necessary to maintain the confidentiality and integrity of the 
information protected by the module.


**Solution:**

Verify that cryptographic modules used by the application have been validated against 
FIPS 140-2 or an equivalent standard.

	